AccessibilityAuditClient

Struct AccessibilityAuditClient 

pub struct AccessibilityAuditClient<S> { /* private fields */ }

Implementations

Source

impl<S> AccessibilityAuditClient<S>
where S: AsyncRead + AsyncWrite + Unpin + Send,

pub fn new(stream: S, product_major_version: u64) -> Self

pub fn new_rsd(stream: S, product_major_version: u64) -> Self

pub fn new_with_handshake( stream: S, product_major_version: u64, handshake: AccessibilityAuditHandshake, ) -> Self

pub async fn publish_capabilities( &mut self, ) -> Result<(), AccessibilityAuditError>

pub async fn capabilities( &mut self, ) -> Result<Vec<String>, AccessibilityAuditError>

pub async fn api_version(&mut self) -> Result<u64, AccessibilityAuditError>

pub async fn supported_audit_types( &mut self, ) -> Result<JsonValue, AccessibilityAuditError>

pub async fn settings(&mut self) -> Result<JsonValue, AccessibilityAuditError>

pub async fn set_app_monitoring_enabled( &mut self, enabled: bool, ) -> Result<(), AccessibilityAuditError>

pub async fn set_monitored_event_type( &mut self, event_type: u64, ) -> Result<(), AccessibilityAuditError>

pub async fn set_show_ignored_elements( &mut self, enabled: bool, ) -> Result<(), AccessibilityAuditError>

pub async fn set_show_visuals( &mut self, enabled: bool, ) -> Result<(), AccessibilityAuditError>

pub async fn set_audit_target_pid( &mut self, pid: u64, ) -> Result<(), AccessibilityAuditError>

pub async fn focus_on_element(&mut self) -> Result<(), AccessibilityAuditError>

pub async fn preview_on_element( &mut self, ) -> Result<(), AccessibilityAuditError>

pub async fn highlight_issue(&mut self) -> Result<(), AccessibilityAuditError>

pub async fn move_focus( &mut self, direction: MoveDirection, ) -> Result<(), AccessibilityAuditError>

pub async fn next_event( &mut self, ) -> Result<AuditEvent, AccessibilityAuditError>

pub async fn wait_for_event( &mut self, selector: &str, ) -> Result<AuditEvent, AccessibilityAuditError>

pub async fn wait_for_monitored_event_type_changed( &mut self, ) -> Result<(), AccessibilityAuditError>

pub async fn run_audit( &mut self, audit_types: &[String], ) -> Result<JsonValue, AccessibilityAuditError>

pub async fn next_focus_change( &mut self, ) -> Result<FocusElement, AccessibilityAuditError>

pub async fn next_focus_change_with_idle_timeout( &mut self, idle_timeout: Duration, ) -> Result<Option<FocusElement>, AccessibilityAuditError>

pub async fn navigate( &mut self, direction: MoveDirection, timeout: Duration, ) -> Result<Option<FocusElement>, AccessibilityAuditError>

Navigate focus in the given direction and return the newly focused element.

pub async fn perform_action_activate( &mut self, element_bytes: &[u8], ) -> Result<(), AccessibilityAuditError>

Perform the Activate action on the currently focused element.

element_bytes should be the raw platform identifier bytes from FocusElement.