#[repr(u64)]pub enum Domain {
AppDataContainer = 1,
AppGroupDataContainer = 2,
Temporary = 3,
RootStaging = 4,
SystemCrashLogs = 5,
}Expand description
Fileservice domain identifiers used by CoreDevice.
Some domains require an app bundle identifier or app group identifier when creating the session. Temporary and root staging domains use an empty identifier.
Variants
AppDataContainer = 1
Per-application data container.
AppGroupDataContainer = 2
App group data container.
Temporary = 3
Device temporary fileservice domain.
RootStaging = 4
Root staging domain used by reference tools for upload staging.
SystemCrashLogs = 5
System crash log domain.