pub fn save_pair_record(
record: &FullPairRecord,
escrow_bag: &[u8],
wifi_mac: Option<&str>,
path: &Path,
) -> Result<(), LockdownError>Expand description
Save a FullPairRecord to disk as a plist file compatible with
PairRecord::load().
The saved record includes all certificates, host private key, root private key, HostID, SystemBUID, EscrowBag, and optionally the WiFi MAC address.